Struct MsgSetMarketsHardCap
pub struct MsgSetMarketsHardCap {
pub authority: String,
pub hard_cap_for_markets: u32,
}Expand description
MsgSetMarketsHardCap is used to set a hard cap on the number of markets listed
Fields
hard_cap_for_markets: u32Hard cap for the total number of markets listed